@@ -26,16 +26,16 @@ class HomeAssistantCog(commands.Cog):
     @commands.has_role("Shiny")
     async def vacuum(self, context: discord.Interaction, choices: str):
         roomba = ha.Vacuum()
-        getattr(roomba, choices)()
-        await context.response.send_message(f"Vacuum is {choices}ing")
+        status = getattr(roomba, choices)()
+        await context.response.send_message(f"Vacuum is {status or choices}ing")
 
     @app_commands.command(name="alarm")
     @app_commands.choices(choices=get_functions(ha.Alarm))
     @commands.has_role("Shiny")
     async def arm(self, context: discord.Interaction, choices: str):
         alarm = ha.Alarm()
-        getattr(alarm, choices)()
-        await context.response.send_message(f"Alarm is {choices}ing")
+        status = getattr(alarm, choices)()
+        await context.response.send_message(f"Alarm is {status or choices}ing")
 
     @app_commands.command(name="taylor_swiftly")
     @app_commands.choices(choices=get_functions(ha.TaylorSwiftly()))
@@ -43,7 +43,7 @@ class HomeAssistantCog(commands.Cog):
     async def tesla(self, context: discord.Interaction, choices: str):
         taylor = ha.TaylorSwiftly()
         status = taylor.get_functions()[choices]()
-        await context.response.send_message(f"Taylor Swiftly is {status}")
+        await context.response.send_message(f"Taylor Swiftly is {choices} is {status}")
 
 
 async def setup(client: commands.Cog):
