@@ -1,7 +1,6 @@
 """Home Assistant module for Shiny API."""
 import inspect
 import os
-from pprint import pprint
 from homeassistant_api import Client
 import shiny_api.modules.load_config as config
 
@@ -123,9 +122,6 @@ class TaylorSwiftly:
         for class_name, class_method in vars(self).items():
             for name in class_method.get_functions():
                 methods[f"{name} {class_name}"] = getattr(class_method, name)
-        # for method in inspect.getmembers(cls, predicate=inspect.):
-        #    print(method)
-        # methods = [method for method, _ in inspect.getmembers(cls, predicate=inspect.isfunction) if not method.startswith("__")]
         return methods
 
 
@@ -136,5 +132,5 @@ if __name__ == "__main__":
     taylor_batt = Sensor("taylor_swiftly_battery", location="home")
     # taylor.lock()
     taylor = TaylorSwiftly()
-    taylor.get_functions()["lock lock"]()
+    # taylor.get_functions()["lock lock"]()
     print(taylor.get_functions())
